# requests-scitokens

`requests-scitokens` provides an authentication plugin for
[Requests](http://requests.readthedocs.io/) that handles attaching
[SciTokens](https://scitokens.org) to HTTP requests.

[![requests-scitokens PyPI version badge](https://badge.fury.io/py/requests-scitokens.svg)](http://badge.fury.io/py/requests-scitokens)
[![requests-scitokens conda-forge badge](https://img.shields.io/conda/vn/conda-forge/requests-scitokens.svg)](https://anaconda.org/conda-forge/requests-scitokens/)

[![requests-scitokens license badge](https://img.shields.io/pypi/l/requests-scitokens.svg)](https://choosealicense.com/licenses/apache-2.0/)
![Supported Python versions badge](https://img.shields.io/pypi/pyversions/requests-scitokens.svg)

[![Build status](https://git.ligo.org/computing/software/requests-scitokens/badges/main/pipeline.svg)](https://git.ligo.org/computing/software/requests-scitokens/-/pipelines)
![Code coverage](https://git.ligo.org/computing/software/requests-scitokens/badges/main/coverage.svg)
[![Documentation Status](https://readthedocs.org/projects/requests-scitokens/badge/?version=latest)](https://requests-scitokens.readthedocs.io/en/latest/?badge=latest)

For full documentation see

<https://requests-scitokens.readthedocs.io/>
